@@ -13,8 +13,6 @@ import urllib.parse
 from json.decoder import JSONDecodeError
 from pathlib import Path
 
-import click
-
 from pipenv.cmdparse import Script
 from pipenv.environment import Environment
 from pipenv.environments import Setting, is_in_virtualenv, normalize_pipfile_path
@@ -26,11 +24,11 @@ from pipenv.utils.constants import is_type_checking
 from pipenv.utils.dependencies import (
     get_canonical_names,
     is_editable,
-    is_star,
     pep423_name,
     python_version,
 )
 from pipenv.utils.internet import get_url_name, is_pypi_url, is_valid_url, proper_case
+from pipenv.utils.locking import atomic_open_for_write
 from pipenv.utils.shell import (
     find_requirements,
     find_windows_executable,
@@ -42,7 +40,7 @@ from pipenv.utils.shell import (
     system_which,
 )
 from pipenv.utils.toml import cleanup_toml, convert_toml_outline_tables
-from pipenv.vendor import plette, toml, tomlkit, vistir
+from pipenv.vendor import click, plette, toml, tomlkit
 from pipenv.vendor.requirementslib.models.utils import get_default_pyproject_backend
 
 try:
@@ -488,7 +486,6 @@ class Project:
 
     @property
     def pipfile_location(self) -> str:
-
         from pipenv.utils.pipfile import find_pipfile
 
         if self.s.PIPENV_PIPFILE:
@@ -844,9 +841,7 @@ class Project:
         """Write out the lockfile."""
         s = self._lockfile_encoder.encode(content)
         open_kwargs = {"newline": self._lockfile_newlines, "encoding": "utf-8"}
-        with vistir.contextmanagers.atomic_open_for_write(
-            self.lockfile_location, **open_kwargs
-        ) as f:
+        with atomic_open_for_write(self.lockfile_location, **open_kwargs) as f:
             f.write(s)
             # Write newline at end of document. GH-319.
             # Only need '\n' here; the file object handles the rest.
@@ -977,12 +972,12 @@ class Project:
         # Set empty group if it doesn't exist yet.
         if category not in p:
             p[category] = {}
-        name = self.get_package_name_in_pipfile(req_name, category=category)
-        if name and is_star(converted):
-            # Skip for wildcard version
-            return
         # Add the package to the group.
-        p[category][name or pep423_name(req_name)] = converted
+        name = self.get_package_name_in_pipfile(req_name, category=category)
+        normalized_name = pep423_name(req_name)
+        if name and name != normalized_name:
+            self.remove_package_from_pipfile(name, category=category)
+        p[category][normalized_name] = converted
         # Write Pipfile.
         self.write_toml(p)
 
