@@ -3,6 +3,7 @@ import queue
 import sys
 import warnings
 from collections import defaultdict
+from tempfile import NamedTemporaryFile
 
 from pipenv import environments, exceptions
 from pipenv.patched.pip._internal.exceptions import PipError
@@ -10,7 +11,7 @@ from pipenv.patched.pip._vendor import rich
 from pipenv.routines.lock import do_lock
 from pipenv.utils.dependencies import convert_deps_to_pip, is_star
 from pipenv.utils.indexes import get_source_list
-from pipenv.utils.internet import download_file, is_valid_url
+from pipenv.utils.internet import download_file, get_host_and_port, is_valid_url
 from pipenv.utils.pip import (
     format_pip_error,
     format_pip_output,
@@ -22,7 +23,10 @@ from pipenv.utils.pipfile import ensure_pipfile
 from pipenv.utils.project import ensure_project
 from pipenv.utils.requirements import import_requirements
 from pipenv.utils.virtualenv import cleanup_virtualenv, do_create_virtualenv
-from pipenv.vendor import click, vistir
+from pipenv.vendor import click
+from pipenv.vendor.requirementslib import fileutils
+from pipenv.vendor.requirementslib.models.requirements import Requirement
+from pipenv.vendor.requirementslib.utils import temp_environ
 
 console = rich.console.Console()
 err = rich.console.Console(stderr=True)
@@ -48,7 +52,7 @@ def do_install(
     extra_pip_args=None,
     categories=None,
 ):
-    requirements_directory = vistir.path.create_tracked_tempdir(
+    requirements_directory = fileutils.create_tracked_tempdir(
         suffix="-requirements", prefix="pipenv-"
     )
     warnings.filterwarnings("default", category=ResourceWarning)
@@ -108,7 +112,7 @@ def do_install(
             bold=True,
             err=True,
         )
-        fd = vistir.path.create_tracked_tempfile(
+        fd = NamedTemporaryFile(
             prefix="pipenv-", suffix="-requirement.txt", dir=requirements_directory
         )
         temp_reqs = fd.name
@@ -234,7 +238,7 @@ def do_install(
                 bold=True,
             )
             # pip install:
-            with vistir.contextmanagers.temp_environ(), console.status(
+            with temp_environ(), console.status(
                 "Installing...", spinner=project.s.PIPENV_SPINNER
             ) as st:
                 if not system:
@@ -334,8 +338,21 @@ def do_install(
                 )
                 # Add the package to the Pipfile.
                 if index_url:
+                    trusted_hosts = get_trusted_hosts()
+                    host_and_port = get_host_and_port(index_url)
+                    require_valid_https = not any(
+                        (
+                            v in trusted_hosts
+                            for v in (
+                                host_and_port,
+                                host_and_port.partition(":")[
+                                    0
+                                ],  # also check if hostname without port is in trusted_hosts
+                            )
+                        )
+                    )
                     index_name = project.add_index_to_pipfile(
-                        index_url, verify_ssl=index_url.startswith("https:")
+                        index_url, verify_ssl=require_valid_https
                     )
                     pkg_requirement.index = index_name
                 try:
@@ -362,7 +379,7 @@ def do_install(
                 st.console.print(
                     environments.PIPENV_SPINNER_OK_TEXT.format("Installation Succeeded")
                 )
-            # Update project settings with pre preference.
+            # Update project settings with pre-release preference.
             if pre:
                 project.update_settings({"allow_prereleases": pre})
         do_init(
@@ -412,7 +429,7 @@ def do_sync(
     )
 
     # Install everything.
-    requirements_dir = vistir.path.create_tracked_tempdir(
+    requirements_dir = fileutils.create_tracked_tempdir(
         suffix="-requirements", prefix="pipenv-"
     )
     if system:
@@ -460,15 +477,14 @@ def do_install_dependencies(
         else:
             categories = ["packages"]
 
+    lockfile = None
+    pipfile = None
     for category in categories:
         # Load the lockfile if it exists, or if dev_only is being used.
-        if skip_lock or not project.lockfile_exists:
+        if skip_lock:
             if not bare:
                 click.secho("Installing dependencies from Pipfile...", bold=True)
-            # skip_lock should completely bypass the lockfile (broken in 4dac1676)
-            lockfile = project.get_or_create_lockfile(
-                categories=categories, from_pipfile=True
-            )
+            pipfile = project.get_pipfile_section(category)
         else:
             lockfile = project.get_or_create_lockfile(categories=categories)
             if not bare:
@@ -479,9 +495,14 @@ def do_install_dependencies(
                     bold=True,
                 )
         dev = dev or dev_only
-        deps_list = list(
-            lockfile.get_requirements(dev=dev, only=dev_only, categories=[category])
-        )
+        if lockfile:
+            deps_list = list(
+                lockfile.get_requirements(dev=dev, only=dev_only, categories=[category])
+            )
+        else:
+            deps_list = []
+            for req_name, specifier in pipfile.items():
+                deps_list.append(Requirement.from_pipfile(req_name, specifier))
         failed_deps_queue = queue.Queue()
         if skip_lock:
             ignore_hashes = True
@@ -574,7 +595,7 @@ def batch_install_iteration(
         elif dep.is_vcs:
             is_artifact = True
 
-    with vistir.contextmanagers.temp_environ():
+    with temp_environ():
         if not allow_global:
             os.environ["PIP_USER"] = "0"
             if "PYTHONHOME" in os.environ:
@@ -772,7 +793,7 @@ def do_init(
     if not deploy:
         ensure_pipfile(project, system=system)
     if not requirements_dir:
-        requirements_dir = vistir.path.create_tracked_tempdir(
+        requirements_dir = fileutils.create_tracked_tempdir(
             suffix="-requirements", prefix="pipenv-"
         )
     # Write out the lockfile if it doesn't exist, but not if the Pipfile is being ignored
