@@ -9,7 +9,7 @@ from pathlib import Path
 from shutil import get_terminal_size
 
 from pipenv.vendor import shellingham
-from pipenv.vendor.vistir.contextmanagers import temp_environ
+from pipenv.vendor.requirementslib.utils import temp_environ
 
 ShellDetectionFailure = shellingham.ShellDetectionFailure
 
@@ -44,9 +44,12 @@ def _get_activate_script(cmd, venv):
     elif "csh" in cmd:
         suffix = ".csh"
         command = "source"
+    elif "xonsh" in cmd:
+        suffix = ".xsh"
+        command = "source"
     elif "nu" in cmd:
         suffix = ".nu"
-        command = "source"
+        command = "overlay use"
     else:
         suffix = ""
         command = "."
