@@ -30,10 +30,9 @@ from pipenv.patched.pip._vendor import pkg_resources, rich
 from pipenv.project import Project
 from pipenv.vendor import click
 from pipenv.vendor.requirementslib import Requirement
+from pipenv.vendor.requirementslib.fileutils import create_tracked_tempdir, open_file
 from pipenv.vendor.requirementslib.models.requirements import Line
 from pipenv.vendor.requirementslib.models.utils import DIRECT_URL_RE
-from pipenv.vendor.vistir import open_file
-from pipenv.vendor.vistir.path import create_tracked_tempdir
 
 try:
     # this is only in Python3.8 and later
@@ -257,7 +256,6 @@ class Resolver:
         markers_lookup: Dict[str, str] = None,
         project: Optional[Project] = None,
     ) -> Tuple[Requirement, Dict[str, str], Dict[str, str]]:
-
         if index_lookup is None:
             index_lookup = {}
         if markers_lookup is None:
@@ -435,7 +433,6 @@ class Resolver:
         pre: bool = False,
         category: str = None,
     ) -> "Resolver":
-
         if not req_dir:
             req_dir = create_tracked_tempdir(suffix="-requirements", prefix="pipenv-")
         if index_lookup is None:
@@ -655,7 +652,7 @@ class Resolver:
         with global_tempdir_manager(), get_build_tracker() as build_tracker, TempDirectory() as directory:
             pip_options = self.pip_options
             finder = self.finder
-            wheel_cache = WheelCache(pip_options.cache_dir, pip_options.format_control)
+            wheel_cache = WheelCache(pip_options.cache_dir)
             preparer = self.pip_command.make_requirement_preparer(
                 temp_build_dir=directory,
                 options=pip_options,
@@ -705,7 +702,6 @@ class Resolver:
                     requires_python = candidate.link.requires_python
                     if requires_python:
                         try:
-
                             marker = marker_from_specifier(requires_python)
                             self.markers[result.name] = marker
                             result.markers = marker
@@ -912,7 +908,6 @@ def actually_resolve_deps(
 
 
 def resolve(cmd, st, project):
-    from pipenv._compat import decode_output
     from pipenv.cmdparse import Script
     from pipenv.vendor.click import echo
 
@@ -920,7 +915,6 @@ def resolve(cmd, st, project):
     is_verbose = project.s.is_verbose()
     err = ""
     for line in iter(c.stderr.readline, ""):
-        line = decode_output(line)
         if not line.rstrip():
             continue
         err += line
@@ -975,8 +969,8 @@ def venv_resolve_deps(
     :param Dict[str, Any] lockfile: A project lockfile to mutate, defaults to None
     :param bool keep_outdated: Whether to retain outdated dependencies and resolve with them in mind, defaults to False
     :raises RuntimeError: Raised on resolution failure
-    :return: Nothing
-    :rtype: None
+    :return: The lock data
+    :rtype: dict
     """
     from pipenv import resolver
 
@@ -991,7 +985,7 @@ def venv_resolve_deps(
 
     if not pipfile:
         pipfile = getattr(project, category, {})
-    if not lockfile:
+    if lockfile is None:
         lockfile = project._lockfile(categories=[category])
     req_dir = create_tracked_tempdir(prefix="pipenv", suffix="requirements")
     cmd = [
@@ -1065,7 +1059,7 @@ def venv_resolve_deps(
         os.unlink(target_file.name)
     if lockfile_section not in lockfile:
         lockfile[lockfile_section] = {}
-    prepare_lockfile(results, pipfile, lockfile[lockfile_section])
+    return prepare_lockfile(results, pipfile, lockfile[lockfile_section])
 
 
 def resolve_deps(
